@@ -2,16 +2,14 @@ from __future__ import unicode_literals
 
 import unittest
 
-import pygst
-pygst.require('0.10')
-import gst
+import mopidy.mixer
 
 from mopidy_nad import mixer
 
 
 class MixerTest(unittest.TestCase):
 
-    def test_is_a_gstreamer_mixer(self):
-        self.assert_(issubclass(mixer.NadMixer, gst.Element))
+    def test_is_a_mopidy_mixer(self):
+        self.assert_(issubclass(mixer.NadMixer, mopidy.mixer.Mixer))
 
     # TODO Add more tests
